@@ -147,9 +147,9 @@ mod logging_pipe_test {
     fn write_without_endl_does_not_consume_buffer_after_flush() {
         let mut pipe = LoggingPipe::new("TestPipe", 0);
 
-        let test_buffer = "Testing write".as_bytes();
+        let test_buffer = b"Testing write";
 
-        pipe.write(test_buffer).expect("Err write");
+        pipe.write_all(test_buffer).expect("Err write");
         pipe.flush().expect("Err flush");
 
         assert_eq!(pipe.buffer.len(), test_buffer.len());
@@ -159,9 +159,9 @@ mod logging_pipe_test {
     fn write_with_single_endl_at_the_end_consumes_whole_buffer_after_flush() {
         let mut pipe = LoggingPipe::new("TestPipe", 0);
 
-        let test_buffer = "Testing write \n".as_bytes();
+        let test_buffer = b"Testing write \n";
 
-        pipe.write(test_buffer).expect("Err write");
+        pipe.write_all(test_buffer).expect("Err write");
         pipe.flush().expect("Err flush");
 
         assert_eq!(pipe.buffer.len(), 0);
@@ -171,10 +171,10 @@ mod logging_pipe_test {
     fn write_with_endl_in_the_middle_consumes_buffer_up_to_endl_after_flush() {
         let mut pipe = LoggingPipe::new("TestPipe", 0);
 
-        let test_buffer = "Testing write \n".as_bytes();
-        let test_buffer2 = "And the rest".as_bytes();
+        let test_buffer = b"Testing write \n";
+        let test_buffer2: &[_] = b"And the rest";
 
-        pipe.write(
+        pipe.write_all(
             [
                 test_buffer,
                 test_buffer,
@@ -195,9 +195,9 @@ mod logging_pipe_test {
     fn write_with_many_endl_consumes_whole_buffer_after_flush() {
         let mut pipe = LoggingPipe::new("TestPipe", 0);
 
-        let test_buffer = "Testing write \n".as_bytes();
+        let test_buffer: &[_] = b"Testing write \n";
 
-        pipe.write(
+        pipe.write_all(
             [
                 test_buffer,
                 test_buffer,
@@ -223,7 +223,7 @@ mod logging_pipe_test {
         // make sure it's not valid utf-8 string if we drop last symbol
         assert!(std::str::from_utf8(&test_buffer[..test_buffer.len() - 1]).is_err());
 
-        pipe.write(&test_buffer[..test_buffer.len() - 1])
+        pipe.write_all(&test_buffer[..test_buffer.len() - 1])
             .expect("Err write");
         pipe.flush().expect("Err flush");
 
@@ -235,9 +235,9 @@ mod logging_pipe_test {
     #[test]
     fn write_with_many_endls_consumes_everything_after_flush() {
         let mut pipe = LoggingPipe::new("TestPipe", 0);
-        let test_buffer = "Testing write \n".as_bytes();
+        let test_buffer: &[_] = b"Testing write \n";
 
-        pipe.write(
+        pipe.write_all(
             [test_buffer, test_buffer, b"\n", b"\n", b"\n"]
                 .concat()
                 .as_slice(),
