@@ -22,12 +22,6 @@ pub trait Overlayable {
     fn generate_overlay(&self, size: Size) -> String;
 }
 
-#[derive(Clone, Debug)]
-struct Padding {
-    rows: usize,
-    cols: usize,
-}
-
 #[derive(Clone, Debug)]
 pub enum OverlayType {
     Prompt(prompt::Prompt),
